==> spirit_hub-0.0.1.10.tar.gz: spirit_hub-0.0.1.10/e2e/cypress/e2e/features/views/favorites.js <==
import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';

// Counts categories
Given('There is some docs to count', () => {
  cy.appFactories([['create_list', 'tagset_doc', 1, { responsible: '1', tagset_ids: [] }]]);
  cy.appFactories([['create_list', 'tagset_doc', 2, { accounted: ['1'], percent: 20, parent_tagset_ids: ['A'] }]]);
  cy.appFactories([['create_list', 'tagset_doc', 3, { informed: ['other_user'], responsible: '1', parent_tagset_ids: ['A'], percent: 100 }]]);
});

Then('I should see the right counts', () => {
  cy.get('.category_count').eq(0).contains(1);
  cy.get('.category_count').eq(1).contains(2);
  cy.get('.category_count').eq(2).contains(3);
});

When('I click on the first category', () => {
  cy.get('.category_count').eq(0).click();
});

When('I click on the second category', () => {
  cy.get('.category_count').eq(1).click();
});

// Right colums
Given('There is one favorites with all columns', () => {
  cy.appFactories([['create', 'doc_favorite', 'with_file', 'with_informed', { user_id: '1' }]]);
});

Then('I should see the right columns', () => {
  cy.get('#model_table td').eq(2).contains('Doc Title 1');
  cy.get('#model_table td').eq(3).contains('7.1 Ko');
  cy.get('#model_table td').eq(4).contains(new Date().toLocaleDateString('fr-FR'));
  cy.get('#model_table td').eq(5).find('div').should('exist');
  cy.get('#model_table td').eq(6).find('img').should('exist');
  cy.get('#model_table td').eq(7).contains('Classé');
  cy.get('#model_table td').eq(8).find('a').should('exist');
});

// Sort
Given('There is some docs and tagset', () => {
  cy.appFactories([['create_list', 'doc_favorite', 5, { user_id: '1' }]]);
  cy.appFactories([['create_list', 'tagset_favorite', 5, { user_id: '1' }]]);
});

When('I click on the title sort', () => {
  cy.wait(300);
  cy.get('#model_table th').eq(2).find('a').click();
});

When('I click on the status sort', () => {
  cy.wait(300);
  cy.get('#model_table th').eq(7).find('a').click();
});

Then('The table is sorted by title desc', () => {
  cy.get('#model_table td').eq(2).contains('Tagset Title 5');
});

Then('The table is sorted by title asc', () => {
  cy.get('#model_table td').eq(2).contains('Doc Title 1');
});

Then('The table is sorted by status asc', () => {
  cy.get('#model_table td').eq(7).contains('Classé');
});

Then('The table is sorted by status desc', () => {
  cy.get('#model_table td').eq(7).contains('Complet');
});

// Per page and pagination
Given('There is a lot of docs and tagset', () => {
  cy.appFactories([['create_list', 'doc_favorite', 5, { user_id: '1' }]]);
  cy.appFactories([['create_list', 'tagset_favorite', 35, { user_id: '1' }]]);
});

When('I go to page 5', () => {
  cy.get('.pagination a').contains('5').click();
});

Then('I am on page 1 and i see 8 pages', () => {
  cy.get('#model_table tbody tr').should('have.length', 5);
  cy.get('.pagination a').eq(0).should('have.class', 'cursor-not-allowed');
  cy.get('.pagination a.bg-primary').contains('1');
  cy.get('.pagination a').eq(6).contains('...');
  cy.get('.pagination a').eq(7).contains('8');
});

Then('I am on page 5 and i see 8 pages', () => {
  cy.get('#model_table tbody tr').should('have.length', 5);
  cy.get('.pagination a').eq(0).should('not.have.class', 'cursor-not-allowed');

  cy.get('.pagination a').eq(2).contains('...');
  cy.get('.pagination a.bg-primary').contains('5');
  cy.get('.pagination a').eq(8).contains('...');
  cy.get('.pagination a').eq(9).contains('8');
});

Then('I am on page 1 and i see 2 pages', () => {
  cy.get('#model_table tbody tr').should('have.length', 20);
  cy.get('.pagination a').eq(0).should('have.class', 'cursor-not-allowed');
  cy.get('.pagination a.bg-primary').contains('1');
  cy.get('.pagination a').eq(2).contains('2');
});

// Logs
Given('There is a doc with logs and a tagset without logs', () => {
  cy.appFactories([['create', 'doc_favorite', 'with_logs', { user_id: '1' }]]);
  cy.appFactories([['create', 'tagset_favorite', { user_id: '1' }]]);
});

When('I click on the logs button on the doc', () => {
  cy.get('#model_table tbody tr:first td:eq(4)').find('button').click();
});

Given('There is some doc and tagset of different types', () => {
  cy.appFactories([['create', 'doc_favorite', { user_id: '1' }]]);
  cy.appFactories([['create', 'doc_favorite', { user_id: '1' }]]);
  cy.appFactories([['create_list', 'tagset_favorite', 5, { user_id: '1' }]]);
});

When('I click on the logs button on the tagset', () => {
  cy.get('#model_table tbody tr:eq(1) td:eq(4)').find('button').click();
});

When('I click outside the logs', () => {
  cy.get('body h1').first().click();
});

When('I click on the close log button', () => {
  cy.get('#model_table tbody tr:eq(1) td:eq(4) #tagset_logs').find('button').click();
});

Then('I should see the doc logs', () => {
  cy.get('.logs').should('be.visible');
  cy.get('.log').should('have.length', 21);
});

Then('I should not see the doc logs', () => {
  cy.get('.logs').should('not.be.visible');
  cy.get('.log').should('have.length', 21);
});

Then('I should see the tagset logs', () => {
  cy.get('#tagset_logs p').contains('Aucun log');
});

Then('I should not see the tagset logs', () => {
  cy.get('#tagset_logs').should('not.be.visible');
});

// Remove from favorite
When('I remove the first and last element from favorite', () => {
  cy.get('#model_table tbody tr:first td:eq(0) a').click();
  cy.get('#model_table tbody tr:last td:eq(0) a').click();
});

Then('The favorites are removed', () => {
  cy.get('#model_table tbody tr').should('have.length', 8);
});

When('I remove the first and last element from favorite in the grid view', () => {
  cy.get('a').filter('[href*="/remove"]').first().click();
  cy.get('a').filter('[href*="/remove"]').last().click();
});

Then('The other favorites are removed', () => {
  cy.get('#model_table tbody tr').should('have.length', 6);
});

// Go to doc_view
Given('There is one tagset_doc with file', () => {
  cy.appFactories([['create', 'doc_favorite', 'with_file', { user_id: '1' }]]);
});

When('I click on the first doc view link', () => {
  cy.get('a').filter('[href*="/doc"]').first().click({ force: true });
});

Then('I should be on the doc_view page', () => {
  cy.url().should('include', '/doc');
});

// Go to directory_view
Given('There is one taget_directory', () => {
  cy.appFactories([['create', 'tagset_favorite', { user_id: '1' }]]);
});

When('I click on the first directory view link', () => {
  cy.get('a').filter('[href*="/index"]').first().click({ force: true });
});

Then('I should be on the directory_view page', () => {
  cy.url().should('include', '/index');
});

Given('There is some docs', () => {
  cy.appFactories([['create_list', 'doc_favorite', 6, { user_id: '1' }]]);
});

// Add doc
Then('I should see the to cagtegorize count increase', () => {
  cy.get('.category_count').eq(0).contains(1);
});

Given('There is a doc to validate on my favorites page', () => {
  let tagset_id;
  cy.appFactories([['create', 'tagset_doc', 'with_state', 'with_informed', { state_key: 'to_validate' }]]).then(records => {
    tagset_id = records[0].id;
    cy.appFactories([['create', 'favorite', { tagset_id: tagset_id, user_id: '1' }]]);
  });
});

==> spirit_hub-0.0.1.11.tar.gz: spirit_hub-0.0.1.11/e2e/cypress/e2e/features/views/favorites.js <==
import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';

// Counts categories
Given('There is some docs to count', () => {
  cy.appFactories([['create_list', 'tagset_doc', 1, { responsible: '1', tagset_ids: [] }]]);
  cy.appFactories([['create_list', 'tagset_doc', 2, { accounted: ['1'], percent: 20, parent_tagset_ids: ['A'] }]]);
  cy.appFactories([['create_list', 'tagset_doc', 3, { informed: ['other_user'], responsible: '1', parent_tagset_ids: ['A'], percent: 100 }]]);
});

Then('I should see the right counts', () => {
  cy.get('.category_count').eq(0).contains(1);
  cy.get('.category_count').eq(1).contains(2);
  cy.get('.category_count').eq(2).contains(3);
});

When('I click on the first category', () => {
  cy.get('.category_count').eq(0).click();
});

When('I click on the second category', () => {
  cy.get('.category_count').eq(1).click();
});

// Right colums
Given('There is one favorites with all columns', () => {
  cy.appFactories([['create', 'doc_favorite', 'with_file', 'with_informed', { user_id: '1' }]]);
});

Then('I should see the right columns', () => {
  cy.get('#model_table td').eq(2).contains('Doc Title 1');
  cy.get('#model_table td').eq(3).contains('7.1 Ko');
  cy.get('#model_table td').eq(4).contains(new Date().toLocaleDateString('fr-FR'));
  cy.get('#model_table td').eq(5).find('div').should('exist');
  cy.get('#model_table td').eq(6).find('img').should('exist');
  cy.get('#model_table td').eq(7).contains('Classé');
  cy.get('#model_table td').eq(8).find('a').should('exist');
});

// Sort
Given('There is some docs and tagset', () => {
  cy.appFactories([['create_list', 'doc_favorite', 5, { user_id: '1' }]]);
  cy.appFactories([['create_list', 'tagset_favorite', 5, { user_id: '1' }]]);
});

When('I click on the title sort', () => {
  cy.wait(300);
  cy.get('#model_table th').eq(2).find('a').click();
});

When('I click on the status sort', () => {
  cy.wait(300);
  cy.get('#model_table th').eq(7).find('a').click();
});

Then('The table is sorted by title desc', () => {
  cy.get('#model_table td').eq(2).contains('Tagset Title 5');
});

Then('The table is sorted by title asc', () => {
  cy.get('#model_table td').eq(2).contains('Doc Title 1');
});

Then('The table is sorted by status asc', () => {
  cy.get('#model_table td').eq(7).contains('Classé');
});

Then('The table is sorted by status desc', () => {
  cy.get('#model_table td').eq(7).contains('Complet');
});

// Per page and pagination
Given('There is a lot of docs and tagset', () => {
  cy.appFactories([['create_list', 'doc_favorite', 5, { user_id: '1' }]]);
  cy.appFactories([['create_list', 'tagset_favorite', 35, { user_id: '1' }]]);
});

When('I go to page 5', () => {
  cy.get('.pagination a').contains('5').click();
});

Then('I am on page 1 and i see 8 pages', () => {
  cy.get('#model_table tbody tr').should('have.length', 5);
  cy.get('.pagination a').eq(0).should('have.class', 'cursor-not-allowed');
  cy.get('.pagination a.bg-primary').contains('1');
  cy.get('.pagination a').eq(6).contains('...');
  cy.get('.pagination a').eq(7).contains('8');
});

Then('I am on page 5 and i see 8 pages', () => {
  cy.get('#model_table tbody tr').should('have.length', 5);
  cy.get('.pagination a').eq(0).should('not.have.class', 'cursor-not-allowed');

  cy.get('.pagination a').eq(2).contains('...');
  cy.get('.pagination a.bg-primary').contains('5');
  cy.get('.pagination a').eq(8).contains('...');
  cy.get('.pagination a').eq(9).contains('8');
});

Then('I am on page 1 and i see 2 pages', () => {
  cy.get('#model_table tbody tr').should('have.length', 20);
  cy.get('.pagination a').eq(0).should('have.class', 'cursor-not-allowed');
  cy.get('.pagination a.bg-primary').contains('1');
  cy.get('.pagination a').eq(2).contains('2');
});

// journal_entries
Given('There is a doc with journal_entries and a tagset without journal_entries', () => {
  cy.appFactories([['create', 'doc_favorite', 'with_journal_entries', { user_id: '1' }]]);
  cy.appFactories([['create', 'tagset_favorite', { user_id: '1' }]]);
});

When('I click on the journal_entries button on the doc', () => {
  cy.get('#model_table tbody tr:first td:eq(4)').find('button').click();
});

Given('There is some doc and tagset of different types', () => {
  cy.appFactories([['create', 'doc_favorite', { user_id: '1' }]]);
  cy.appFactories([['create', 'doc_favorite', { user_id: '1' }]]);
  cy.appFactories([['create_list', 'tagset_favorite', 5, { user_id: '1' }]]);
});

When('I click on the journal_entries button on the tagset', () => {
  cy.get('#model_table tbody tr:eq(1) td:eq(4)').find('button').click();
});

When('I click outside the journal_entries', () => {
  cy.get('body h1').first().click();
});

When('I click on the close log button', () => {
  cy.get('#model_table tbody tr:eq(1) td:eq(4) #journal_entries').find('button').click();
});

Then('I should see the doc journal_entries', () => {
  cy.get('.journal_entry').should('be.visible');
  cy.get('.journal_entry').should('have.length', 21);
});

Then('I should not see the doc journal_entries', () => {
  cy.get('.journal_entry').should('not.be.visible');
});

Then('I should see the tagset journal_entries', () => {
  cy.get('#journal_entries ').contains('Aucun historique');
});

Then('I should not see the tagset journal_entries', () => {
  cy.get('#journal_entries').should('not.be.visible');
});

// Remove from favorite
When('I remove the first and last element from favorite', () => {
  cy.get('#model_table tbody tr:first td:eq(0) a').click();
  cy.get('#model_table tbody tr:last td:eq(0) a').click();
});

Then('The favorites are removed', () => {
  cy.get('#model_table tbody tr').should('have.length', 8);
});

When('I remove the first and last element from favorite in the grid view', () => {
  cy.get('a').filter('[href*="/remove"]').first().click();
  cy.get('a').filter('[href*="/remove"]').last().click();
});

Then('The other favorites are removed', () => {
  cy.get('#model_table tbody tr').should('have.length', 6);
});

// Go to doc_view
Given('There is one tagset_doc with file', () => {
  cy.appFactories([['create', 'doc_favorite', 'with_file', { user_id: '1' }]]);
});

When('I click on the first doc view link', () => {
  cy.get('a').filter('[href*="/doc"]').first().click({ force: true });
});

Then('I should be on the doc_view page', () => {
  cy.url().should('include', '/doc');
});

// Go to directory_view
Given('There is one taget_directory', () => {
  cy.appFactories([['create', 'tagset_favorite', { user_id: '1' }]]);
});

When('I click on the first directory view link', () => {
  cy.get('a').filter('[href*="/index"]').first().click({ force: true });
});

Then('I should be on the directory_view page', () => {
  cy.url().should('include', '/index');
});

Given('There is some docs', () => {
  cy.appFactories([['create_list', 'doc_favorite', 6, { user_id: '1' }]]);
});

// Add doc
Then('I should see the to cagtegorize count increase', () => {
  cy.get('.category_count').eq(0).contains(1);
});

Given('There is a doc to validate on my favorites page', () => {
  let tagset_id;
  cy.appFactories([['create', 'tagset_doc', 'with_state', 'with_informed', { state_key: 'to_validate' }]]).then(records => {
    tagset_id = records[0].id;
    cy.appFactories([['create', 'favorite', { tagset_id: tagset_id, user_id: '1' }]]);
  });
});
